@@ -191,6 +191,15 @@ case $type in
                 fi
             done
         fi
+        if [ ".$algo" = ".DSA" ]; then
+            echo ""
+            echo "${T_MD}WARNING!${T_ME} You're generating a DSA based certificate/key pair."
+            echo "         This implies that RSA based ciphers won't be available later,"
+            echo "         which for your web server currently still means that mostly all"
+            echo "         popular web browsers cannot connect to it. At least not until"
+            echo "         you also generate an additional RSA based certificate/key pair"
+            echo "         and configure them in parallel."
+        fi
         echo "______________________________________________________________________"
         echo ""
         echo "${T_MD}STEP 1: Generating $algo private key (1024 bit) [server.key]${T_ME}"
@@ -411,6 +420,15 @@ EOT
                 fi
             done
         fi
+        if [ ".$algo" = ".DSA" ]; then
+            echo ""
+            echo "${T_MD}WARNING!${T_ME} You're generating DSA based certificate/key pairs."
+            echo "         This implies that RSA based ciphers won't be available later,"
+            echo "         which for your web server currently still means that mostly all"
+            echo "         popular web browsers cannot connect to it. At least not until"
+            echo "         you also generate an additional RSA based certificate/key pair"
+            echo "         and configure them in parallel."
+        fi
         echo "______________________________________________________________________"
         echo ""
         echo "${T_MD}STEP 1: Generating $algo private key for CA (1024 bit) [ca.key]${T_ME}"
